@@ -31,8 +31,8 @@ pub enum Method {
 }
 
 impl From<Method> for Bytes {
-    fn from(s: Method) -> Self {
-        match s {
+    fn from(x: Method) -> Self {
+        match x {
             Method::Get => Bytes::from_static(b"GET"),
             Method::Head => Bytes::from_static(b"HEAD"),
             Method::Post => Bytes::from_static(b"POST"),
@@ -47,7 +47,7 @@ impl From<Method> for Bytes {
 }
 
 #[inline]
-pub fn get_method(v: &[u8]) -> Result<Method, MethodError> {
+pub fn parse_method(v: &[u8]) -> Result<Method, MethodError> {
     if v.len() < 3 || v.len() > 7 {
         return Err(MethodError::InvalidMethod);
     }
